local E, L, V, P, G = unpack(ElvUI)
local MyPluginName = "ThinkTankUI"

local ThinkTankUI = E:GetModule(MyPluginName);
local EP = LibStub("LibElvUIPlugin-1.0")
local addon = ...

local pairs, tinsert, tremove, unpack = pairs, tinsert, tremove, unpack
local format = format
local _G = _G
local ceil, format, checkTable = ceil, format, next
local tinsert, twipe, tsort, tconcat = table.insert, table.wipe, table.sort, table.concat

-- WoW API / Variables

local IsAddOnLoaded = IsAddOnLoaded
local ReloadUI = ReloadUI
local FCF_SetLocked = FCF_SetLocked
local FCF_DockFrame, FCF_UnDockFrame = FCF_DockFrame, FCF_UnDockFrame
local FCF_SavePositionAndDimensions = FCF_SavePositionAndDimensions
local FCF_GetChatWindowInfo = FCF_GetChatWindowInfo
local FCF_StopDragging = FCF_StopDragging
local FCF_SetChatWindowFontSize = FCF_SetChatWindowFontSize
local NUM_CHAT_WINDOWS = NUM_CHAT_WINDOWS
local ADDONS, LOOT, TRADE, TANK, HEALER = ADDONS, LOOT, TRADE, TANK, HEALER
ThinkTankUI.Version = GetAddOnMetadata('ElvUI_ThinkTankUI_RM', 'Version')

--Runs for the step questioning the user if they want a new ElvUI profile
local function NewProfile(new)
	if (new) then -- the user clicked "Create New" create a dialog pop up
		StaticPopupDialogs["CreateProfileNameNew"] = {
		text = L["Name for the new profile"],
		button1 = L["Accept"],
		button2 = L["Cancel"],
		hasEditBox = 1,
		whileDead = 1,
		hideOnEscape = 1,
		timeout = 0,
		OnShow = function(self, data)
		  self.editBox:SetText("ThinkTankUI"); --default text in the editbox
		end,
		OnAccept = function(self, data, data2)
		  local text = self.editBox:GetText()
		  ElvUI[1].data:SetProfile(text) --ElvUI function for changing profiles, creates a new profile if name doesn't exist
		  PluginInstallStepComplete.message = "Profile Created"
		  PluginInstallStepComplete:Show()
		end
	  };
	  StaticPopup_Show("CreateProfileNameNew", "test"); --tell our dialog box to show
	elseif(new == false) then -- the user clicked "Use Current" create a dialog pop up
		StaticPopupDialogs["ProfileOverrideConfirm"] = {
			text = "Are you sure you want to override the current profile?",
			button1 = "Yes",
			button2 = "No",
			OnAccept = function()
			    PluginInstallStepComplete.message = "Profile Selected"
		        PluginInstallStepComplete:Show()
			end,
			timeout = 0,
			whileDead = true,
			hideOnEscape = true,
		}
		StaticPopup_Show("ProfileOverrideConfirm", "test")--tell our dialog box to show
	end
end
local function SetupChat()
	for i = 1, NUM_CHAT_WINDOWS do
		local frame = _G[format("ChatFrame%s", i)]
		local chatFrameId = frame:GetID()
		local chatName = FCF_GetChatWindowInfo(chatFrameId)

		FCF_SetChatWindowFontSize(nil, frame, 13)

		-- move ElvUI default loot frame to the left chat, so that Recount/Skada can go to the right chat.
		if i == 3 and chatName == LOOT.." / "..TRADE then
			FCF_UnDockFrame(frame)
			frame:ClearAllPoints()
			frame:Point("BOTTOMLEFT", LeftChatToggleButton, "TOPLEFT", 1, 3)
			FCF_SetWindowName(frame, LOOT)
			FCF_DockFrame(frame)
			if not frame.isLocked then
				FCF_SetLocked(frame, 1)
			end
			frame:Show()
		end
		FCF_SavePositionAndDimensions(frame)
		FCF_StopDragging(frame)
	end
	ChatFrame_RemoveChannel(ChatFrame3, L["Trade"])
	ChatFrame_AddChannel(ChatFrame1, L["Trade"])
	ChatFrame_AddMessageGroup(ChatFrame1, "TARGETICONS")
	ChatFrame_AddMessageGroup(ChatFrame3, "COMBAT_FACTION_CHANGE")
	ChatFrame_AddMessageGroup(ChatFrame3, "COMBAT_GUILD_XP_GAIN")
	ChatFrame_AddMessageGroup(ChatFrame3, "COMBAT_HONOR_GAIN")
	ChatFrame_AddMessageGroup(ChatFrame3, "COMBAT_XP_GAIN")
	ChatFrame_AddMessageGroup(ChatFrame3, "CURRENCY")
	ChatFrame_AddMessageGroup(ChatFrame3, "LOOT")
	ChatFrame_AddMessageGroup(ChatFrame3, "MONEY")
	ChatFrame_AddMessageGroup(ChatFrame3, "SKILL")

	-- Enable classcolor automatically on login and on each character without doing /configure each time
	ToggleChatColorNamesByClassGroup(true, "ACHIEVEMENT")
	ToggleChatColorNamesByClassGroup(true, "BATTLEGROUND_LEADER")
	ToggleChatColorNamesByClassGroup(true, "BATTLEGROUND")
	ToggleChatColorNamesByClassGroup(true, "CHANNEL1")
	ToggleChatColorNamesByClassGroup(true, "CHANNEL10")
	ToggleChatColorNamesByClassGroup(true, "CHANNEL11")
	ToggleChatColorNamesByClassGroup(true, "CHANNEL2")
	ToggleChatColorNamesByClassGroup(true, "CHANNEL3")
	ToggleChatColorNamesByClassGroup(true, "CHANNEL4")
	ToggleChatColorNamesByClassGroup(true, "CHANNEL5")
	ToggleChatColorNamesByClassGroup(true, "CHANNEL6")
	ToggleChatColorNamesByClassGroup(true, "CHANNEL7")
	ToggleChatColorNamesByClassGroup(true, "CHANNEL8")
	ToggleChatColorNamesByClassGroup(true, "CHANNEL9")
	ToggleChatColorNamesByClassGroup(true, "EMOTE")
	ToggleChatColorNamesByClassGroup(true, "GUILD_ACHIEVEMENT")
	ToggleChatColorNamesByClassGroup(true, "GUILD")
	ToggleChatColorNamesByClassGroup(true, "INSTANCE_CHAT_LEADER")
	ToggleChatColorNamesByClassGroup(true, "INSTANCE_CHAT")
	ToggleChatColorNamesByClassGroup(true, "OFFICER")
	ToggleChatColorNamesByClassGroup(true, "PARTY_LEADER")
	ToggleChatColorNamesByClassGroup(true, "PARTY")
	ToggleChatColorNamesByClassGroup(true, "RAID_LEADER")
	ToggleChatColorNamesByClassGroup(true, "RAID_WARNING")
	ToggleChatColorNamesByClassGroup(true, "RAID")
	ToggleChatColorNamesByClassGroup(true, "SAY")
	ToggleChatColorNamesByClassGroup(true, "WHISPER")
	ToggleChatColorNamesByClassGroup(true, "YELL")
	--chat options--
	
	E.db["chat"]["tabFontOutline"] = "OUTLINE"
	E.db["chat"]["keywordSound"] = "Whisper Alert"
	E.db["chat"]["timeStampFormat"] = "%H:%M "
	E.db["chat"]["tabFontSize"] = 12
	E.db["chat"]["editBoxPosition"] = "ABOVE_CHAT"
	E.db["chat"]["panelTabTransparency"] = true
	E.db["chat"]["panelHeight"] = 152
	E.db["chat"]["panelWidthRight"] = 400
	E.db["chat"]["chatHistory"] = false
	E.db["chat"]["keywords"] = "%MYNAME%, ElvUI, ThinkTankUI"
	E.db["chat"]["panelHeightRight"] = 152
	E.db["chat"]["font"] = "Expressway"
	E.db["chat"]["copyChatLines"] = true
	E.db["chat"]["tabFont"] = "Expressway"
	E.db["chat"]["separateSizes"] = true
	E.db["chat"]["panelWidth"] = 400
		
	PluginInstallStepComplete.message = ThinkTankUI.Title..L['Chat Set']
	PluginInstallStepComplete:Show()
	E:UpdateAll(true)
	end
	
	
local function SetupLayout()
		-- common settings
		E.db["databars"]["azerite"]["height"] = 174
		E.db["databars"]["azerite"]["width"] = 8
		E.db["databars"]["experience"]["height"] = 12
		E.db["databars"]["experience"]["orientation"] = "HORIZONTAL"
		E.db["databars"]["experience"]["width"] = 180
		E.db["databars"]["honor"]["height"] = 12
		E.db["databars"]["honor"]["orientation"] = "HORIZONTAL"
		E.db["databars"]["honor"]["width"] = 411
		E.db["databars"]["reputation"]["enable"] = true
		E.db["databars"]["reputation"]["height"] = 12
		E.db["databars"]["reputation"]["orientation"] = "HORIZONTAL"
		E.db["databars"]["reputation"]["width"] = 400
		E.db["databars"]["threat"]["font"] = "Expressway"
		E.db["databars"]["threat"]["height"] = 12
		E.db["datatexts"]["font"] = "Expressway"
		E.db["datatexts"]["fontOutline"] = "OUTLINE"
		E.db["datatexts"]["panels"]["BottomMiniPanel"] = "Time"
		E.db["datatexts"]["panels"]["LeftChatDataPanel"][3] = "Guild"
		E.db["datatexts"]["panels"]["LeftChatDataPanel"]["left"] = "Talent/Loot Specialization"
		E.db["datatexts"]["panels"]["LeftChatDataPanel"]["middle"] = "Durability"
		E.db["datatexts"]["panels"]["LeftChatDataPanel"]["panelTransparency"] = true
		E.db["datatexts"]["panels"]["LeftChatDataPanel"]["right"] = "Guild"
		E.db["datatexts"]["panels"]["LeftCoordDtPanel"] = "Guild"
		E.db["datatexts"]["panels"]["MinimapPanel"]["enable"] = false
		E.db["datatexts"]["panels"]["RightChatDataPanel"]["enable"] = false
		E.db["datatexts"]["panels"]["RightChatDataPanel"]["left"] = "Bags"
		E.db["datatexts"]["panels"]["RightChatDataPanel"]["middle"] = "Gold"
		E.db["datatexts"]["panels"]["RightChatDataPanel"]["right"] = "Talent/Loot Specialization"
		E.db["datatexts"]["panels"]["RightCoordDtPanel"] = "Friends"
		E.db["datatexts"]["panels"]["RightMiniPanel"] = ""
		E.db["general"]["backdropcolor"]["b"] = 0.10196078431373
		E.db["general"]["backdropcolor"]["g"] = 0.10196078431373
		E.db["general"]["backdropcolor"]["r"] = 0.10196078431373
		E.db["general"]["backdropfadecolor"]["a"] = 0.8500000089407
		E.db["general"]["backdropfadecolor"]["b"] = 0.058823529411765
		E.db["general"]["backdropfadecolor"]["g"] = 0.058823529411765
		E.db["general"]["backdropfadecolor"]["r"] = 0.058823529411765
		E.db["general"]["bonusObjectivePosition"] = "RIGHT"
		E.db["general"]["bottomPanel"] = false
		E.db["general"]["font"] = "Expressway"
		E.db["general"]["minimap"]["icons"]["calendar"]["position"] = "BOTTOMRIGHT"
		E.db["general"]["minimap"]["icons"]["lfgEye"]["position"] = "RIGHT"
		E.db["general"]["minimap"]["locationFont"] = "Expressway"
		E.db["general"]["objectiveFrameHeight"] = 700
		E.db["general"]["totems"]["spacing"] = 3
		E.db["general"]["valuecolor"]["b"] = 0.73
		E.db["general"]["valuecolor"]["g"] = 0.55
		E.db["general"]["valuecolor"]["r"] = 0.96
		E.db["chat"]["chatHistory"] = false
		E.db["chat"]["copyChatLines"] = true
		E.db["chat"]["editBoxPosition"] = "ABOVE_CHAT"
		E.db["chat"]["font"] = "Expressway"
		E.db["chat"]["fontSize"] = 12
		E.db["chat"]["keywordSound"] = "Whisper Alert"
		E.db["chat"]["keywords"] = "%MYNAME%, ElvUI, ThinkTankUI"
		E.db["chat"]["panelHeight"] = 152
		E.db["chat"]["panelHeightRight"] = 174
		E.db["chat"]["panelTabTransparency"] = true
		E.db["chat"]["panelWidth"] = 400
		E.db["chat"]["panelWidthRight"] = 400
		E.db["chat"]["separateSizes"] = true
		E.db["chat"]["tabFont"] = "Expressway"
		E.db["chat"]["tabFontOutline"] = "OUTLINE"
		E.db["chat"]["timeStampFormat"] = "%H:%M "
		E.private["skins"]["blizzard"]["alertframes"] = true
		E.private["auras"]["enable"] = false
		
		E.private["general"]["normTex"] = "ElvUI Blank"
		E.private["general"]["glossTex"] = "ElvUI Blank"
		E.private["general"]["chatBubbles"] = 'backdrop'
		
		--WindTools--
		E.db["WT"]["combat"]["combatAlert"]["animationSize"] = 0.5
		E.db["WT"]["item"]["extraItemsBar"]["enable"] = false
		E.db["WT"]["item"]["fastLoot"]["enable"] = false
		E.db["WT"]["misc"]["gameBar"]["additionalText"]["font"]["name"] = "Expressway"
		E.db["WT"]["misc"]["gameBar"]["backdropSpacing"] = 6
		E.db["WT"]["misc"]["gameBar"]["buttonSize"] = 20
		E.db["WT"]["misc"]["gameBar"]["time"]["font"]["name"] = "Expressway"
		E.db["WT"]["misc"]["gameBar"]["time"]["font"]["size"] = 26
		E.db["WT"]["misc"]["gameBar"]["time"]["twentyFour"] = false
		E.db["WT"]["misc"]["gameBar"]["timeAreaHeight"] = 32
		E.db["WT"]["misc"]["gameBar"]["timeAreaWidth"] = 80
		E.db["WT"]["quest"]["turnIn"]["enable"] = false
		E.db["WT"]["social"]["chatBar"]["buttonHeight"] = 21
		E.db["WT"]["social"]["chatBar"]["buttonWidth"] = 6
		E.db["WT"]["social"]["chatBar"]["orientation"] = "VERTICAL"
		E.db["WT"]["social"]["chatBar"]["spacing"] = 4
		E.db["WT"]["social"]["chatBar"]["tex"] = "ElvUI Blank"
		E.db["WT"]["social"]["emote"]["enable"] = false
	
		E.private["WT"]["maps"]["minimapButtons"]["backdrop"] = false
		E.private["WT"]["maps"]["minimapButtons"]["buttonSize"] = 20
		E.private["WT"]["maps"]["minimapButtons"]["mouseOver"] = true
		
		--nameplates
		E.db["actionbar"]["bar4"]["buttonsPerRow"] = 12
		E.db["actionbar"]["bar4"]["alpha"] = 0.75
		E.db["actionbar"]["bar4"]["backdrop"] = false
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["countFontSize"] = 12
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["countFont"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["spacing"] = 3
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["durationPosition"] = "TOP"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["priority"] = "Blacklist,Personal,CCDebuffs"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["size"] = 28
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["yOffset"] = 11
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["portrait"]["height"] = 20
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["portrait"]["width"] = 20
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["portrait"]["xOffset"] = 5
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["portrait"]["yOffset"] = 0
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["power"]["displayAltPower"] = true
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["raidTargetIndicator"]["xOffset"] = -5
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["raidTargetIndicator"]["size"] = 18
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["countFontSize"] = 11
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["countFont"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["anchorPoint"] = "TOPRIGHT"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["growthX"] = "LEFT"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["durationPosition"] = "TOP"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["size"] = 28
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["spacing"] = 3
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["yOffset"] = 42
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["title"]["format"] = "[npctitle]"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["height"] = 10
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["iconOffsetX"] = 3
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["iconOffsetY"] = -5
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["iconSize"] = 18
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["width"] = 130
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["xOffset"] = -10
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["yOffset"] = -22
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["format"] = "[name:long]"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["fontSize"] = 12
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["yOffset"] = -4
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["xOffset"] = 2
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["format"] = "[difficultycolor][level][shortclassification]"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["fontSize"] = 12
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["yOffset"] = -4
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["height"] = 16
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["text"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["text"]["fontSize"] = 12
		E.db["nameplates"]["units"]["TARGET"]["classpower"]["yOffset"] = 53
		E.db["nameplates"]["units"]["TARGET"]["classpower"]["width"] = 122
		E.db["nameplates"]["units"]["TARGET"]["glowStyle"] = "style1"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["countFontSize"] = 12
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["countFont"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["spacing"] = 3
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["durationPosition"] = "TOPLEFT"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["priority"] = "Blacklist,Personal,CCDebuffs"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["size"] = 28
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["yOffset"] = 11
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["portrait"]["height"] = 20
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["portrait"]["width"] = 20
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["portrait"]["xOffset"] = 5
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["portrait"]["yOffset"] = 0
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["height"] = 10
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["iconOffsetX"] = 3
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["iconOffsetY"] = -5
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["iconSize"] = 18
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["width"] = 130
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["xOffset"] = -10
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["yOffset"] = -22
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["questIcon"]["xOffset"] = 5
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["questIcon"]["size"] = 18
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["raidTargetIndicator"]["xOffset"] = -5
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["raidTargetIndicator"]["size"] = 18
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["format"] = "[name:long]"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["fontSize"] = 12
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["yOffset"] = -4
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["xOffset"] = 2
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["fontSize"] = 12
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["yOffset"] = -4
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["countFontSize"] = 11
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["countFont"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["anchorPoint"] = "TOPRIGHT"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["growthX"] = "LEFT"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["durationPosition"] = "TOPLEFT"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["size"] = 28
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["spacing"] = 3
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["yOffset"] = 42
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["height"] = 16
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["text"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["text"]["fontSize"] = 12
		E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["countFontSize"] = 12
		E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["countFont"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["spacing"] = 3
		E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["durationPosition"] = "TOP"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["size"] = 28
		E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["yOffset"] = 11
		E.db["nameplates"]["units"]["ENEMY_NPC"]["portrait"]["height"] = 20
		E.db["nameplates"]["units"]["ENEMY_NPC"]["portrait"]["width"] = 20
		E.db["nameplates"]["units"]["ENEMY_NPC"]["portrait"]["xOffset"] = 5
		E.db["nameplates"]["units"]["ENEMY_NPC"]["portrait"]["yOffset"] = 0
		E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["height"] = 10
		E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["iconOffsetX"] = 3
		E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["iconOffsetY"] = -5
		E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["iconSize"] = 18
		E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["width"] = 130
		E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["xOffset"] = -10
		E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["yOffset"] = -22
		E.db["nameplates"]["units"]["ENEMY_NPC"]["questIcon"]["xOffset"] = 10
		E.db["nameplates"]["units"]["ENEMY_NPC"]["questIcon"]["size"] = 18
		E.db["nameplates"]["units"]["ENEMY_NPC"]["raidTargetIndicator"]["xOffset"] = -5
		E.db["nameplates"]["units"]["ENEMY_NPC"]["raidTargetIndicator"]["size"] = 18
		E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["format"] = "[name:long]"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["fontSize"] = 12
		E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["yOffset"] = -4
		E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["xOffset"] = 2
		E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["fontSize"] = 12
		E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["yOffset"] = -4
		E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["countFontSize"] = 11
		E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["countFont"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["growthX"] = "LEFT"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["yOffset"] = 42
		E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["anchorPoint"] = "TOPRIGHT"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["spacing"] = 3
		E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["priority"] = "Blacklist,blockNoDuration,Personal,TurtleBuffs"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["durationPosition"] = "TOP"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["size"] = 28
		E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["height"] = 16
		E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["fontSize"] = 12
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["countFontSize"] = 12
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["countFont"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["spacing"] = 3
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["durationPosition"] = "TOPLEFT"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["priority"] = "Blacklist,Personal,CCDebuffs"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["size"] = 28
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["yOffset"] = 11
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["portrait"]["height"] = 20
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["portrait"]["width"] = 20
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["portrait"]["xOffset"] = 5
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["portrait"]["yOffset"] = 0
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["power"]["displayAltPower"] = true
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["raidTargetIndicator"]["xOffset"] = -5
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["raidTargetIndicator"]["size"] = 18
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["countFontSize"] = 11
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["countFont"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["growthX"] = "LEFT"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["yOffset"] = 42
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["maxDuration"] = 0
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["spacing"] = 3
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["anchorPoint"] = "TOPRIGHT"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["priority"] = "Blacklist,blockNoDuration,Personal,TurtleBuffs"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["durationPosition"] = "TOPLEFT"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["size"] = 28
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["title"]["format"] = "[npctitle]"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["height"] = 10
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["iconOffsetX"] = 3
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["iconOffsetY"] = -5
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["iconSize"] = 18
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["width"] = 130
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["xOffset"] = -10
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["yOffset"] = -22
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["format"] = "[name:long]"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["fontSize"] = 12
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["yOffset"] = -4
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["xOffset"] = 2
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["format"] = "[difficultycolor][level][shortclassification]"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["fontSize"] = 12
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["yOffset"] = -4
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["height"] = 16
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["font"] = "Expressway"
		E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["fontSize"] = 12
		E.db["nameplates"]["units"]["PLAYER"]["raidTargetIndicator"]["xOffset"] = -20
		E.db["nameplates"]["statusbar"] = "ElvUI Blank"
		E.db["nameplates"]["font"] = "Expressway"
		E.db["nameplates"]["clampToScreen"] = true	
		
		--bags
		E.db["bags"]["countFontSize"] = 12
		E.db["bags"]["countFont"] = "Expressway"
		E.db["bags"]["itemLevelFont"] = "Expressway"
		E.db["bags"]["ignoreItems"] = ""
		E.db["bags"]["bankSize"] = 30
		E.db["bags"]["itemLevelFontSize"] = 12
		E.db["bags"]["bankWidth"] = 500
		E.db["bags"]["bagSize"] = 30
		E.db["bags"]["alignToChat"] = false
		E.db["bags"]["bagWidth"] = 500	
		E.db["bagSortIgnoreItemsReset"] = true

		--tooltips
		E.db["tooltip"]["fontSize"] = 13
		E.db["tooltip"]["healthBar"]["height"] = 14
		E.db["tooltip"]["healthBar"]["fontSize"] = 12
		E.db["tooltip"]["healthBar"]["font"] = "Expressway"
		E.db["tooltip"]["headerFontSize"] = 13
		E.db["tooltip"]["textFontSize"] = 13
		E.db["tooltip"]["showMount"] = true
		E.db["tooltip"]["spellID"] = true
		E.db["tooltip"]["fontOutline"] = "OUTLINE"
		E.db["tooltip"]["font"] = "Florence Sans"
		E.db["tooltip"]["playerTitles"] = false
		E.db["tooltip"]["smallTextFontSize"] = 13
			
		-- Movers
		if E.db["movers"] == nil then E.db["movers"] = {} end
		E.db["movers"]["AltPowerBarMover"] = "TOP,ElvUIParent,TOP,0,-45"
		E.db["movers"]["DurabilityFrameMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,495,4"
		E.db["movers"]["SocialMenuMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,4,-107"
		E.db["movers"]["LeftChatMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,14,4"
		E.db["movers"]["RightChatMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-4,4"
		E.db["movers"]["GMMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,497,-4"
		E.db["movers"]["BossButton"] = "TOP,ElvUIParent,TOP,224,-293"
		E.db["movers"]["LootFrameMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,552,-268"
		E.db["movers"]["ZoneAbility"] = "TOP,ElvUIParent,TOP,-225,-293"
		E.db["movers"]["VehicleLeaveButton"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-550,130"
		E.db["movers"]["VehicleSeatMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-419,33"
		E.db["movers"]["ExperienceBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-9,-190"
		E.db["movers"]["LossControlMover"] = "BOTTOM,ElvUIParent,BOTTOM,-1,489"
		E.db["movers"]["TalkingHeadFrameMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,8,-8"
		E.db["movers"]["ReputationBarMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-4,182"
		E.db["movers"]["ObjectiveFrameMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-71,-245"
		E.db["movers"]["BNETMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,230"
		E.db["movers"]["TotemBarMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,416,4"
		E.db["movers"]["HonorBarMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,3,182"
		E.db["movers"]["TooltipMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-4,230"
		E.db["movers"]["MinimapMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-10,-9"
		E.db["movers"]["AzeriteBarMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-406,4"
		E.db["movers"]["AlertFrameMover"] = "TOP,ElvUIParent,TOP,0,-60"
		E.db["movers"]["VOICECHAT"] = "TOPLEFT,ElvUIParent,TOPLEFT,4,-4"
		E.db["movers"]["ElvUIBagMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-4,4"
		E.db["movers"]["ElvUIBankMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,4"
		E.db["movers"]["ThreatBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,276"
		
		--WindTools--
		E.db["movers"]["WTChatBarMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,6"
		E.db["movers"]["WTGameBarAnchor"] = "TOP,ElvUIParent,TOP,0,-4"
		E.db["movers"]["WTMinimapButtonBarAnchor"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-9,-204"
		E.db["movers"]["WTParagonReputationToastFrameMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,403"
		E.db["movers"]["WTRaidMarkersBarAnchor"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-4,198"

	PluginInstallStepComplete.message = ThinkTankUI.Title..L['Layout Set']
	PluginInstallStepComplete:Show()

	E:UpdateAll(true)
end

	
local function SetupUnitframes(layout)
	if layout == 'v1' then
	E.db.unitframes = nil
	
	--Units
	--general
	E.db["unitframe"]["statusbar"] = "ElvUI Blank"
	E.db["unitframe"]["colors"]["auraBarBuff"]["b"] = 0.43
	E.db["unitframe"]["colors"]["auraBarBuff"]["g"] = 0.61
	E.db["unitframe"]["colors"]["auraBarBuff"]["r"] = 0.78
	E.db["unitframe"]["colors"]["transparentHealth"] = true
	E.db["unitframe"]["colors"]["colorhealthbyvalue"] = false
	E.db["unitframe"]["colors"]["health_backdrop"]["g"] = 0.011764705882353
	E.db["unitframe"]["colors"]["health_backdrop"]["b"] = 0.011764705882353
	E.db["unitframe"]["colors"]["transparentCastbar"] = true
	E.db["unitframe"]["colors"]["transparentPower"] = true
	E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["b"] = 0.74901960784314
	E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["g"] = 0.17254901960784
	E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["r"] = 0.26666666666667
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["b"] = 0.18039215686275
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["g"] = 0.12156862745098
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["r"] = 0.69019607843137
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["b"] = 0.12549019607843
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["g"] = 0.54509803921569
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["r"] = 0.65098039215686
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["b"] = 0.24705882352941
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["g"] = 0.58823529411765
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["r"] = 0.18823529411765
	E.db["unitframe"]["colors"]["power"]["MANA"]["b"] = 0.63137254901961
	E.db["unitframe"]["colors"]["power"]["MANA"]["g"] = 0.45098039215686
	E.db["unitframe"]["colors"]["power"]["MANA"]["r"] = 0.30980392156863
	E.db["unitframe"]["colors"]["castColor"]["b"] = 0.24313725490196
	E.db["unitframe"]["colors"]["castColor"]["g"] = 0.74901960784314
	E.db["unitframe"]["colors"]["castColor"]["r"] = 0.22745098039216
	E.db["unitframe"]["colors"]["castNoInterrupt"]["b"] = 0.31764705882353
	E.db["unitframe"]["colors"]["castNoInterrupt"]["g"] = 0.28627450980392
	E.db["unitframe"]["colors"]["castNoInterrupt"]["r"] = 0.78039215686274
	E.db["unitframe"]["colors"]["classbackdrop"] = true
	E.db["unitframe"]["colors"]["health"]["b"] = 0.10588235294118
	E.db["unitframe"]["colors"]["health"]["g"] = 0.10588235294118
	E.db["unitframe"]["colors"]["health"]["r"] = 0.10588235294118
	E.db["unitframe"]["colors"]["debuffHighlight"]["Poison"]["a"] = 0.25
	E.db["unitframe"]["colors"]["debuffHighlight"]["Disease"]["a"] = 0.25
	E.db["unitframe"]["colors"]["debuffHighlight"]["Magic"]["a"] = 0.25
	E.db["unitframe"]["colors"]["debuffHighlight"]["Curse"]["a"] = 0.25
	E.db["unitframe"]["colors"]["healPrediction"]["personal"]["a"] = 0.15000003576279
	E.db["unitframe"]["colors"]["healPrediction"]["personal"]["b"] = 0.50196078431373
	E.db["unitframe"]["fontOutline"] = "OUTLINE"
	E.db["unitframe"]["font"] = "Expressway"
	E.db["unitframe"]["fontSize"] = 12
	E.db["unitframe"]["smoothbars"] = true
	
	
	--Player
	E.db["unitframe"]["units"]["player"]["debuffs"]["attachTo"] = "HEALTH"
	E.db["unitframe"]["units"]["player"]["debuffs"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["anchorPoint"] = "TOP"
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["color"]["g"] = 0.89411764705882
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["color"]["b"] = 0
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["texture"] = "ALERT"
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["size"] = 13
	E.db["unitframe"]["units"]["player"]["aurabar"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["RestIcon"]["size"] = 15
	E.db["unitframe"]["units"]["player"]["RestIcon"]["xOffset"] = 0
	E.db["unitframe"]["units"]["player"]["RestIcon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["player"]["name"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["power"]["height"] = 8
	E.db["unitframe"]["units"]["player"]["power"]["xOffset"] = 0
	E.db["unitframe"]["units"]["player"]["width"] = 225
	E.db["unitframe"]["units"]["player"]["castbar"]["height"] = 15
	E.db["unitframe"]["units"]["player"]["castbar"]["width"] = 225
	E.db["unitframe"]["units"]["player"]["castbar"]["icon"] = false
	E.db["unitframe"]["units"]["player"]["health"]["bgUseBarTexture"] = false
	E.db["unitframe"]["units"]["player"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["player"]["health"]["text_format"] = "[health:current]"
	E.db["unitframe"]["units"]["player"]["classbar"]["detachFromFrame"] = false
	E.db["unitframe"]["units"]["player"]["classbar"]["detachedWidth"] = 225
	E.db["unitframe"]["units"]["player"]["classbar"]["fill"] = "filled"
	E.db["unitframe"]["units"]["player"]["classbar"]["height"] = 6
	E.db["unitframe"]["units"]["player"]["classbar"]["additionalPowerText"] = false
	E.db["unitframe"]["units"]["player"]["height"] = 40
	E.db["unitframe"]["units"]["player"]["buffs"]["anchorPoint"] = "LEFT"
	E.db["unitframe"]["units"]["player"]["buffs"]["sizeOverride"] = 39
	E.db["unitframe"]["units"]["player"]["buffs"]["attachTo"] = "FRAME"
	E.db["unitframe"]["units"]["player"]["buffs"]["countFont"] = "Expressway"
	E.db["unitframe"]["units"]["player"]["buffs"]["sortDirection"] = "ASCENDING"
	E.db["unitframe"]["units"]["player"]["buffs"]["priority"] = "blockNoDuration,Blacklist,Personal,PlayerBuffs,Whitelist,nonPersonal"
	E.db["unitframe"]["units"]["player"]["buffs"]["noDuration"] = false
	E.db["unitframe"]["units"]["player"]["buffs"]["perrow"] = 6
	E.db["unitframe"]["units"]["player"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["player"]["raidicon"]["yOffset"] = 5
	E.db["unitframe"]["units"]["player"]["raidicon"]["attachToObject"] = "Health"
	E.db["unitframe"]["units"]["player"]["raidicon"]["size"] = 14
	
	--Target
	E.db["unitframe"]["units"]["target"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["target"]["debuffs"]["enable"] = false
	E.db["unitframe"]["units"]["target"]["smartAuraDisplay"] = "DISABLED"
	E.db["unitframe"]["units"]["target"]["aurabar"]["enable"] = false
	E.db["unitframe"]["units"]["target"]["aurabar"]["selfBuffs"] = true
	E.db["unitframe"]["units"]["target"]["name"]["xOffset"] = 4
	E.db["unitframe"]["units"]["target"]["name"]["text_format"] = "||cffb2b2b2[level][difficultycolor][shortclassification] [namecolor][name:medium]"
	E.db["unitframe"]["units"]["target"]["name"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["target"]["castbar"]["height"] = 40
	E.db["unitframe"]["units"]["target"]["castbar"]["width"] = 225
	E.db["unitframe"]["units"]["target"]["width"] = 225
	E.db["unitframe"]["units"]["target"]["power"]["xOffset"] = -2
	E.db["unitframe"]["units"]["target"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["target"]["power"]["height"] = 8
	E.db["unitframe"]["units"]["target"]["height"] = 40
	E.db["unitframe"]["units"]["target"]["orientation"] = "LEFT"
	E.db["unitframe"]["units"]["target"]["buffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["target"]["buffs"]["selfBuffs"] = true
	E.db["unitframe"]["units"]["target"]["buffs"]["enable"] = false
	E.db["unitframe"]["units"]["target"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["target"]["health"]["text_format"] = "[health:current]"
	E.db["unitframe"]["units"]["target"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["target"]["raidicon"]["yOffset"] = 5
	E.db["unitframe"]["units"]["target"]["raidicon"]["attachToObject"] = "Health"
	E.db["unitframe"]["units"]["target"]["raidicon"]["size"] = 14
	
	--Pet
	E.db["unitframe"]["units"]["pet"]["width"] = 100
	E.db["unitframe"]["units"]["pet"]["name"]["attachTextTo"] = "Health"
	E.db["unitframe"]["units"]["pet"]["height"] = 35
	E.db["unitframe"]["units"]["pet"]["castbar"]["enable"] = false
	
	--Focus
	E.db["unitframe"]["units"]["focus"]["debuffs"]["anchorPoint"] = "BOTTOMRIGHT"
	E.db["unitframe"]["units"]["focus"]["debuffs"]["enable"] = false
	E.db["unitframe"]["units"]["focus"]["threatStyle"] = "NONE"
	E.db["unitframe"]["units"]["focus"]["power"]["height"] = 6
	E.db["unitframe"]["units"]["focus"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["focus"]["raidicon"]["xOffset"] = 1
	E.db["unitframe"]["units"]["focus"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["focus"]["raidicon"]["attachToObject"] = "Health"
	E.db["unitframe"]["units"]["focus"]["raidicon"]["size"] = 12
	E.db["unitframe"]["units"]["focus"]["width"] = 90
	E.db["unitframe"]["units"]["focus"]["castbar"]["height"] = 22
	E.db["unitframe"]["units"]["focus"]["castbar"]["width"] = 90
	E.db["unitframe"]["units"]["focus"]["name"]["text_format"] = "[namecolor][name:short]"
	E.db["unitframe"]["units"]["focus"]["height"] = 28
	E.db["unitframe"]["units"]["focus"]["health"]["frequentUpdates"] = true
	
	--TargetTarget
	E.db["unitframe"]["units"]["targettarget"]["debuffs"]["enable"] = false
	E.db["unitframe"]["units"]["targettarget"]["power"]["height"] = 6
	E.db["unitframe"]["units"]["targettarget"]["width"] = 90
	E.db["unitframe"]["units"]["targettarget"]["name"]["text_format"] = "[namecolor][name:short]"
	E.db["unitframe"]["units"]["targettarget"]["height"] = 28
	E.db["unitframe"]["units"]["targettarget"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["xOffset"] = 1
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["attachToObject"] = "Health"
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["size"] = 12
	
	--Party
	E.db["unitframe"]["units"]["party"]["horizontalSpacing"] = 5
	E.db["unitframe"]["units"]["party"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["party"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["party"]["debuffs"]["perrow"] = 5
	E.db["unitframe"]["units"]["party"]["debuffs"]["yOffset"] = 5
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["font"] = "Expressway"
	E.db["unitframe"]["units"]["party"]["growthDirection"] = "RIGHT_UP"
	E.db["unitframe"]["units"]["party"]["buffIndicator"]["size"] = 10
	E.db["unitframe"]["units"]["party"]["roleIcon"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["party"]["targetsGroup"]["anchorPoint"] = "BOTTOM"
	E.db["unitframe"]["units"]["party"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["power"]["height"] = 5
	E.db["unitframe"]["units"]["party"]["width"] = 105
	E.db["unitframe"]["units"]["party"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["name"]["xOffset"] = 2
	E.db["unitframe"]["units"]["party"]["name"]["text_format"] = "[namecolor][name:short] "
	E.db["unitframe"]["units"]["party"]["name"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["party"]["height"] = 35
	E.db["unitframe"]["units"]["party"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["party"]["raidicon"]["yOffset"] = 4
	E.db["unitframe"]["units"]["party"]["raidicon"]["xOffset"] = 32
	E.db["unitframe"]["units"]["party"]["raidicon"]["size"] = 14
	
	--Raid
	E.db["unitframe"]["units"]["raid"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["raid"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["raid"]["debuffs"]["perrow"] = 5
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["font"] = "Expressway"
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["fontOutline"] = "OUTLINE"
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["size"] = 18
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["yOffset"] = 5
	E.db["unitframe"]["units"]["raid"]["growthDirection"] = "RIGHT_UP"
	E.db["unitframe"]["units"]["raid"]["buffIndicator"]["size"] = 9
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["xOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["power"]["height"] = 5
	E.db["unitframe"]["units"]["raid"]["power"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid"]["power"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["health"]["xOffset"] = 2
	E.db["unitframe"]["units"]["raid"]["health"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid"]["health"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["raid"]["orientation"] = "LEFT"
	E.db["unitframe"]["units"]["raid"]["width"] = 105
	E.db["unitframe"]["units"]["raid"]["infoPanel"]["height"] = 15
	E.db["unitframe"]["units"]["raid"]["name"]["text_format"] = "[namecolor][name:short] "
	E.db["unitframe"]["units"]["raid"]["height"] = 35
	E.db["unitframe"]["units"]["raid"]["verticalSpacing"] = -1
	E.db["unitframe"]["units"]["raid"]["buffs"]["perrow"] = 4
	
	--Raid40
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["perrow"] = 5
	E.db["unitframe"]["units"]["raid40"]["portrait"]["camDistanceScale"] = 2
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["font"] = "Expressway"
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["size"] = 14
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["fontOutline"] = "OUTLINE"
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["yOffset"] = 5
	E.db["unitframe"]["units"]["raid40"]["growthDirection"] = "RIGHT_UP"
	E.db["unitframe"]["units"]["raid40"]["buffIndicator"]["size"] = 6
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["xOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["power"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["power"]["height"] = 5
	E.db["unitframe"]["units"]["raid40"]["power"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid40"]["power"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["health"]["xOffset"] = 2
	E.db["unitframe"]["units"]["raid40"]["health"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid40"]["health"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["raid40"]["orientation"] = "LEFT"
	E.db["unitframe"]["units"]["raid40"]["width"] = 105
	E.db["unitframe"]["units"]["raid40"]["infoPanel"]["height"] = 15
	E.db["unitframe"]["units"]["raid40"]["name"]["text_format"] = "[namecolor][name:short] "
	E.db["unitframe"]["units"]["raid40"]["height"] = 26
	E.db["unitframe"]["units"]["raid40"]["verticalSpacing"] = -1
	E.db["unitframe"]["units"]["raid40"]["buffs"]["perrow"] = 4
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["attachToObject"] = "Health"
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["size"] = 14
	
	--Boss
	E.db["unitframe"]["units"]["boss"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["boss"]["debuffs"]["maxDuration"] = 300
	E.db["unitframe"]["units"]["boss"]["debuffs"]["perrow"] = 10
	E.db["unitframe"]["units"]["boss"]["debuffs"]["countFont"] = "Expressway"
	E.db["unitframe"]["units"]["boss"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["boss"]["debuffs"]["yOffset"] = 3
	E.db["unitframe"]["units"]["boss"]["portrait"]["style"] = "2D"
	E.db["unitframe"]["units"]["boss"]["castbar"]["width"] = 200
	E.db["unitframe"]["units"]["boss"]["width"] = 200
	E.db["unitframe"]["units"]["boss"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["boss"]["health"]["text_format"] = "[health:percent]"
	E.db["unitframe"]["units"]["boss"]["spacing"] = 50
	E.db["unitframe"]["units"]["boss"]["height"] = 40
	E.db["unitframe"]["units"]["boss"]["buffs"]["maxDuration"] = 300
	E.db["unitframe"]["units"]["boss"]["buffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["boss"]["buffs"]["xOffset"] = -5
	E.db["unitframe"]["units"]["boss"]["buffs"]["perrow"] = 4
	E.db["unitframe"]["units"]["boss"]["buffs"]["yOffset"] = 0
	
	--Arena
	E.db["unitframe"]["units"]["arena"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["arena"]["debuffs"]["maxDuration"] = 300
	E.db["unitframe"]["units"]["arena"]["debuffs"]["perrow"] = 10
	E.db["unitframe"]["units"]["arena"]["debuffs"]["countFont"] = "Expressway"
	E.db["unitframe"]["units"]["arena"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["arena"]["debuffs"]["yOffset"] = 3
	E.db["unitframe"]["units"]["arena"]["portrait"]["style"] = "2D"
	E.db["unitframe"]["units"]["arena"]["castbar"]["width"] = 200
	E.db["unitframe"]["units"]["arena"]["width"] = 200
	E.db["unitframe"]["units"]["arena"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["arena"]["health"]["text_format"] = "[health:percent]"
	E.db["unitframe"]["units"]["arena"]["spacing"] = 50
	E.db["unitframe"]["units"]["arena"]["height"] = 40
	E.db["unitframe"]["units"]["arena"]["buffs"]["maxDuration"] = 300
	E.db["unitframe"]["units"]["arena"]["buffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["arena"]["buffs"]["xOffset"] = -5
	E.db["unitframe"]["units"]["arena"]["buffs"]["perrow"] = 4
	E.db["unitframe"]["units"]["arena"]["buffs"]["yOffset"] = 0

	--Movers
	if E.db["movers"] == nil then E.db["movers"] = {} end
	E.db["movers"]["ElvUF_FocusCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,-315,395"
	E.db["movers"]["ElvUF_RaidpetMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,4,736"
	E.db["movers"]["ElvUF_FocusMover"] = "BOTTOM,ElvUIParent,BOTTOM,-315,419"
	E.db["movers"]["ElvUF_TargetMover"] = "BOTTOM,ElvUIParent,BOTTOM,248,346"
	E.db["movers"]["ElvUF_PartyMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,62"
	E.db["movers"]["ElvUF_RaidMover"] =  "BOTTOM,ElvUIParent,BOTTOM,0,62"
	E.db["movers"]["ElvUF_Raid40Mover"] = "BOTTOM,ElvUIParent,BOTTOM,0,62"
	E.db["movers"]["ElvUF_TargetTargetMover"] = "BOTTOM,ElvUIParent,BOTTOM,315,391"
	E.db["movers"]["ElvUF_PlayerMover"] = "BOTTOM,ElvUIParent,BOTTOM,-247,346"
	E.db["movers"]["ArenaHeaderMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-283,-260"
	E.db["movers"]["ElvUF_PetMover"] = "BOTTOM,ElvUIParent,BOTTOM,-1,293"
	E.db["movers"]["AltPowerBarMover"] = "TOP,ElvUIParent,TOP,0,0"
	E.db["movers"]["ElvUF_AssistMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,4,603"
	E.db["movers"]["ElvUF_TankMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,4,672"
	E.db["movers"]["ElvUF_TargetCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,1,346"
	E.db["movers"]["BossHeaderMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-283,-260"
	E.db["movers"]["ClassBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,-247,385"
	
	
elseif layout == 'v2' then
	E.db.unitframes = nil
	
	--Units
	--general
	E.db["unitframe"]["statusbar"] = "ElvUI Blank"
	E.db["unitframe"]["colors"]["auraBarBuff"]["b"] = 0.43
	E.db["unitframe"]["colors"]["auraBarBuff"]["g"] = 0.61
	E.db["unitframe"]["colors"]["auraBarBuff"]["r"] = 0.78
	E.db["unitframe"]["colors"]["transparentHealth"] = true
	E.db["unitframe"]["colors"]["colorhealthbyvalue"] = false
	E.db["unitframe"]["colors"]["health_backdrop"]["g"] = 0.011764705882353
	E.db["unitframe"]["colors"]["health_backdrop"]["b"] = 0.011764705882353
	E.db["unitframe"]["colors"]["transparentCastbar"] = true
	E.db["unitframe"]["colors"]["transparentPower"] = true
	E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["b"] = 0.74901960784314
	E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["g"] = 0.17254901960784
	E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["r"] = 0.26666666666667
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["b"] = 0.18039215686275
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["g"] = 0.12156862745098
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["r"] = 0.69019607843137
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["b"] = 0.12549019607843
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["g"] = 0.54509803921569
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["r"] = 0.65098039215686
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["b"] = 0.24705882352941
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["g"] = 0.58823529411765
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["r"] = 0.18823529411765
	E.db["unitframe"]["colors"]["power"]["MANA"]["b"] = 0.63137254901961
	E.db["unitframe"]["colors"]["power"]["MANA"]["g"] = 0.45098039215686
	E.db["unitframe"]["colors"]["power"]["MANA"]["r"] = 0.30980392156863
	E.db["unitframe"]["colors"]["castColor"]["b"] = 0.24313725490196
	E.db["unitframe"]["colors"]["castColor"]["g"] = 0.74901960784314
	E.db["unitframe"]["colors"]["castColor"]["r"] = 0.22745098039216
	E.db["unitframe"]["colors"]["castNoInterrupt"]["b"] = 0.31764705882353
	E.db["unitframe"]["colors"]["castNoInterrupt"]["g"] = 0.28627450980392
	E.db["unitframe"]["colors"]["castNoInterrupt"]["r"] = 0.78039215686274
	E.db["unitframe"]["colors"]["classbackdrop"] = true
	E.db["unitframe"]["colors"]["health"]["b"] = 0.10588235294118
	E.db["unitframe"]["colors"]["health"]["g"] = 0.10588235294118
	E.db["unitframe"]["colors"]["health"]["r"] = 0.10588235294118
	E.db["unitframe"]["colors"]["debuffHighlight"]["Poison"]["a"] = 0.25
	E.db["unitframe"]["colors"]["debuffHighlight"]["Disease"]["a"] = 0.25
	E.db["unitframe"]["colors"]["debuffHighlight"]["Magic"]["a"] = 0.25
	E.db["unitframe"]["colors"]["debuffHighlight"]["Curse"]["a"] = 0.25
	E.db["unitframe"]["colors"]["healPrediction"]["personal"]["a"] = 0.15000003576279
	E.db["unitframe"]["colors"]["healPrediction"]["personal"]["b"] = 0.50196078431373
	E.db["unitframe"]["fontOutline"] = "OUTLINE"
	E.db["unitframe"]["font"] = "Expressway"
	E.db["unitframe"]["fontSize"] = 12
	E.db["unitframe"]["smoothbars"] = true
	
	
	--Player
	E.db["unitframe"]["units"]["player"]["debuffs"]["attachTo"] = "HEALTH"
	E.db["unitframe"]["units"]["player"]["debuffs"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["anchorPoint"] = "TOP"
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["color"]["g"] = 0.89411764705882
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["color"]["b"] = 0
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["texture"] = "ALERT"
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["size"] = 13
	E.db["unitframe"]["units"]["player"]["aurabar"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["RestIcon"]["size"] = 15
	E.db["unitframe"]["units"]["player"]["RestIcon"]["xOffset"] = 0
	E.db["unitframe"]["units"]["player"]["RestIcon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["player"]["name"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["power"]["height"] = 8
	E.db["unitframe"]["units"]["player"]["power"]["xOffset"] = 0
	E.db["unitframe"]["units"]["player"]["width"] = 225
	E.db["unitframe"]["units"]["player"]["castbar"]["height"] = 15
	E.db["unitframe"]["units"]["player"]["castbar"]["width"] = 225
	E.db["unitframe"]["units"]["player"]["castbar"]["icon"] = false
	E.db["unitframe"]["units"]["player"]["health"]["bgUseBarTexture"] = false
	E.db["unitframe"]["units"]["player"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["player"]["health"]["text_format"] = "[health:current]"
	E.db["unitframe"]["units"]["player"]["classbar"]["detachFromFrame"] = false
	E.db["unitframe"]["units"]["player"]["classbar"]["detachedWidth"] = 225
	E.db["unitframe"]["units"]["player"]["classbar"]["fill"] = "filled"
	E.db["unitframe"]["units"]["player"]["classbar"]["height"] = 6
	E.db["unitframe"]["units"]["player"]["classbar"]["additionalPowerText"] = false
	E.db["unitframe"]["units"]["player"]["height"] = 40
	E.db["unitframe"]["units"]["player"]["buffs"]["anchorPoint"] = "LEFT"
	E.db["unitframe"]["units"]["player"]["buffs"]["sizeOverride"] = 39
	E.db["unitframe"]["units"]["player"]["buffs"]["attachTo"] = "FRAME"
	E.db["unitframe"]["units"]["player"]["buffs"]["countFont"] = "Expressway"
	E.db["unitframe"]["units"]["player"]["buffs"]["sortDirection"] = "ASCENDING"
	E.db["unitframe"]["units"]["player"]["buffs"]["priority"] = "blockNoDuration,Blacklist,Personal,PlayerBuffs,Whitelist,nonPersonal"
	E.db["unitframe"]["units"]["player"]["buffs"]["noDuration"] = false
	E.db["unitframe"]["units"]["player"]["buffs"]["perrow"] = 6
	E.db["unitframe"]["units"]["player"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["player"]["raidicon"]["yOffset"] = 5
	E.db["unitframe"]["units"]["player"]["raidicon"]["attachToObject"] = "Health"
	E.db["unitframe"]["units"]["player"]["raidicon"]["size"] = 14
	
	--Target
	E.db["unitframe"]["units"]["target"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["target"]["debuffs"]["enable"] = false
	E.db["unitframe"]["units"]["target"]["smartAuraDisplay"] = "DISABLED"
	E.db["unitframe"]["units"]["target"]["aurabar"]["enable"] = false
	E.db["unitframe"]["units"]["target"]["aurabar"]["selfBuffs"] = true
	E.db["unitframe"]["units"]["target"]["name"]["xOffset"] = 4
	E.db["unitframe"]["units"]["target"]["name"]["text_format"] = "||cffb2b2b2[level][difficultycolor][shortclassification] [namecolor][name:medium]"
	E.db["unitframe"]["units"]["target"]["name"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["target"]["castbar"]["height"] = 40
	E.db["unitframe"]["units"]["target"]["castbar"]["width"] = 225
	E.db["unitframe"]["units"]["target"]["width"] = 225
	E.db["unitframe"]["units"]["target"]["power"]["xOffset"] = -2
	E.db["unitframe"]["units"]["target"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["target"]["power"]["height"] = 8
	E.db["unitframe"]["units"]["target"]["height"] = 40
	E.db["unitframe"]["units"]["target"]["orientation"] = "LEFT"
	E.db["unitframe"]["units"]["target"]["buffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["target"]["buffs"]["selfBuffs"] = true
	E.db["unitframe"]["units"]["target"]["buffs"]["enable"] = false
	E.db["unitframe"]["units"]["target"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["target"]["health"]["text_format"] = "[health:current]"
	E.db["unitframe"]["units"]["target"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["target"]["raidicon"]["yOffset"] = 5
	E.db["unitframe"]["units"]["target"]["raidicon"]["attachToObject"] = "Health"
	E.db["unitframe"]["units"]["target"]["raidicon"]["size"] = 14
	
	--Pet
	E.db["unitframe"]["units"]["pet"]["width"] = 100
	E.db["unitframe"]["units"]["pet"]["name"]["attachTextTo"] = "Health"
	E.db["unitframe"]["units"]["pet"]["height"] = 35
	E.db["unitframe"]["units"]["pet"]["castbar"]["enable"] = false
	
	--Focus
	E.db["unitframe"]["units"]["focus"]["debuffs"]["anchorPoint"] = "BOTTOMRIGHT"
	E.db["unitframe"]["units"]["focus"]["debuffs"]["enable"] = false
	E.db["unitframe"]["units"]["focus"]["threatStyle"] = "NONE"
	E.db["unitframe"]["units"]["focus"]["power"]["height"] = 6
	E.db["unitframe"]["units"]["focus"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["focus"]["raidicon"]["xOffset"] = 1
	E.db["unitframe"]["units"]["focus"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["focus"]["raidicon"]["attachToObject"] = "Health"
	E.db["unitframe"]["units"]["focus"]["raidicon"]["size"] = 12
	E.db["unitframe"]["units"]["focus"]["width"] = 90
	E.db["unitframe"]["units"]["focus"]["castbar"]["height"] = 22
	E.db["unitframe"]["units"]["focus"]["castbar"]["width"] = 90
	E.db["unitframe"]["units"]["focus"]["name"]["text_format"] = "[namecolor][name:short]"
	E.db["unitframe"]["units"]["focus"]["height"] = 28
	E.db["unitframe"]["units"]["focus"]["health"]["frequentUpdates"] = true
	
	--TargetTarget
	E.db["unitframe"]["units"]["targettarget"]["debuffs"]["enable"] = false
	E.db["unitframe"]["units"]["targettarget"]["power"]["height"] = 6
	E.db["unitframe"]["units"]["targettarget"]["width"] = 90
	E.db["unitframe"]["units"]["targettarget"]["name"]["text_format"] = "[namecolor][name:short]"
	E.db["unitframe"]["units"]["targettarget"]["height"] = 28
	E.db["unitframe"]["units"]["targettarget"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["xOffset"] = 1
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["attachToObject"] = "Health"
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["size"] = 12
	
	--Party
	E.db["unitframe"]["units"]["party"]["horizontalSpacing"] = 5
	E.db["unitframe"]["units"]["party"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["party"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["party"]["debuffs"]["perrow"] = 5
	E.db["unitframe"]["units"]["party"]["debuffs"]["yOffset"] = 5
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["font"] = "Expressway"
	E.db["unitframe"]["units"]["party"]["growthDirection"] = "RIGHT_UP"
	E.db["unitframe"]["units"]["party"]["buffIndicator"]["size"] = 10
	E.db["unitframe"]["units"]["party"]["roleIcon"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["party"]["targetsGroup"]["anchorPoint"] = "BOTTOM"
	E.db["unitframe"]["units"]["party"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["power"]["height"] = 5
	E.db["unitframe"]["units"]["party"]["width"] = 105
	E.db["unitframe"]["units"]["party"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["name"]["xOffset"] = 2
	E.db["unitframe"]["units"]["party"]["name"]["text_format"] = "[namecolor][name:short] "
	E.db["unitframe"]["units"]["party"]["name"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["party"]["height"] = 45
	E.db["unitframe"]["units"]["party"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["party"]["raidicon"]["yOffset"] = 4
	E.db["unitframe"]["units"]["party"]["raidicon"]["xOffset"] = 32
	E.db["unitframe"]["units"]["party"]["raidicon"]["size"] = 14
	
	--Raid
	E.db["unitframe"]["units"]["raid"]["horizontalSpacing"] = -1
	E.db["unitframe"]["units"]["raid"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["raid"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["raid"]["debuffs"]["perrow"] = 5
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["font"] = "Expressway"
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["fontOutline"] = "OUTLINE"
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["size"] = 18
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["yOffset"] = 5
	E.db["unitframe"]["units"]["raid"]["growthDirection"] = "RIGHT_UP"
	E.db["unitframe"]["units"]["raid"]["buffIndicator"]["size"] = 9
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["xOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["power"]["height"] = 5
	E.db["unitframe"]["units"]["raid"]["power"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid"]["power"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["health"]["xOffset"] = 2
	E.db["unitframe"]["units"]["raid"]["health"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid"]["health"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["raid"]["orientation"] = "LEFT"
	E.db["unitframe"]["units"]["raid"]["width"] = 105
	E.db["unitframe"]["units"]["raid"]["infoPanel"]["height"] = 15
	E.db["unitframe"]["units"]["raid"]["name"]["text_format"] = "[namecolor][name:short] "
	E.db["unitframe"]["units"]["raid"]["height"] = 40
	E.db["unitframe"]["units"]["raid"]["verticalSpacing"] = -1
	E.db["unitframe"]["units"]["raid"]["buffs"]["perrow"] = 4
	
	--Raid40
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["perrow"] = 5
	E.db["unitframe"]["units"]["raid40"]["portrait"]["camDistanceScale"] = 2
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["font"] = "Expressway"
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["size"] = 14
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["fontOutline"] = "OUTLINE"
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["yOffset"] = 5
	E.db["unitframe"]["units"]["raid40"]["growthDirection"] = "RIGHT_UP"
	E.db["unitframe"]["units"]["raid40"]["buffIndicator"]["size"] = 6
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["xOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["power"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["power"]["height"] = 5
	E.db["unitframe"]["units"]["raid40"]["power"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid40"]["power"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["health"]["xOffset"] = 2
	E.db["unitframe"]["units"]["raid40"]["health"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid40"]["health"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["raid40"]["orientation"] = "LEFT"
	E.db["unitframe"]["units"]["raid40"]["width"] = 105
	E.db["unitframe"]["units"]["raid40"]["infoPanel"]["height"] = 15
	E.db["unitframe"]["units"]["raid40"]["name"]["text_format"] = "[namecolor][name:short] "
	E.db["unitframe"]["units"]["raid40"]["height"] = 26
	E.db["unitframe"]["units"]["raid40"]["verticalSpacing"] = -1
	E.db["unitframe"]["units"]["raid40"]["buffs"]["perrow"] = 4
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["attachToObject"] = "Health"
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["size"] = 14
	
	--Boss
	E.db["unitframe"]["units"]["boss"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["boss"]["debuffs"]["maxDuration"] = 300
	E.db["unitframe"]["units"]["boss"]["debuffs"]["perrow"] = 10
	E.db["unitframe"]["units"]["boss"]["debuffs"]["countFont"] = "Expressway"
	E.db["unitframe"]["units"]["boss"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["boss"]["debuffs"]["yOffset"] = 3
	E.db["unitframe"]["units"]["boss"]["portrait"]["style"] = "2D"
	E.db["unitframe"]["units"]["boss"]["castbar"]["width"] = 200
	E.db["unitframe"]["units"]["boss"]["width"] = 200
	E.db["unitframe"]["units"]["boss"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["boss"]["health"]["text_format"] = "[health:percent]"
	E.db["unitframe"]["units"]["boss"]["spacing"] = 50
	E.db["unitframe"]["units"]["boss"]["height"] = 40
	E.db["unitframe"]["units"]["boss"]["buffs"]["maxDuration"] = 300
	E.db["unitframe"]["units"]["boss"]["buffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["boss"]["buffs"]["xOffset"] = -5
	E.db["unitframe"]["units"]["boss"]["buffs"]["perrow"] = 4
	E.db["unitframe"]["units"]["boss"]["buffs"]["yOffset"] = 0
	
	--Arena
	E.db["unitframe"]["units"]["arena"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["arena"]["debuffs"]["maxDuration"] = 300
	E.db["unitframe"]["units"]["arena"]["debuffs"]["perrow"] = 10
	E.db["unitframe"]["units"]["arena"]["debuffs"]["countFont"] = "Expressway"
	E.db["unitframe"]["units"]["arena"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["arena"]["debuffs"]["yOffset"] = 3
	E.db["unitframe"]["units"]["arena"]["portrait"]["style"] = "2D"
	E.db["unitframe"]["units"]["arena"]["castbar"]["width"] = 200
	E.db["unitframe"]["units"]["arena"]["width"] = 200
	E.db["unitframe"]["units"]["arena"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["arena"]["health"]["text_format"] = "[health:percent]"
	E.db["unitframe"]["units"]["arena"]["spacing"] = 50
	E.db["unitframe"]["units"]["arena"]["height"] = 40
	E.db["unitframe"]["units"]["arena"]["buffs"]["maxDuration"] = 300
	E.db["unitframe"]["units"]["arena"]["buffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["arena"]["buffs"]["xOffset"] = -5
	E.db["unitframe"]["units"]["arena"]["buffs"]["perrow"] = 4
	E.db["unitframe"]["units"]["arena"]["buffs"]["yOffset"] = 0

	--Movers
	if E.db["movers"] == nil then E.db["movers"] = {} end
	E.db["movers"]["ElvUF_FocusCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,-315,395"
	E.db["movers"]["ElvUF_RaidpetMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,4,736"
	E.db["movers"]["ElvUF_FocusMover"] = "BOTTOM,ElvUIParent,BOTTOM,-315,419"
	E.db["movers"]["ElvUF_TargetMover"] = "BOTTOM,ElvUIParent,BOTTOM,248,346"
	E.db["movers"]["ElvUF_PartyMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,62"
	E.db["movers"]["ElvUF_RaidMover"] =  "BOTTOM,ElvUIParent,BOTTOM,0,62"
	E.db["movers"]["ElvUF_Raid40Mover"] =  "BOTTOM,ElvUIParent,BOTTOM,0,62"
	E.db["movers"]["ElvUF_TargetTargetMover"] = "BOTTOM,ElvUIParent,BOTTOM,315,391"
	E.db["movers"]["ElvUF_PlayerMover"] = "BOTTOM,ElvUIParent,BOTTOM,-247,346"
	E.db["movers"]["ArenaHeaderMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-283,-260"
	E.db["movers"]["ElvUF_PetMover"] = "BOTTOM,ElvUIParent,BOTTOM,-1,293"
	E.db["movers"]["AltPowerBarMover"] = "TOP,ElvUIParent,TOP,0,-45"
	E.db["movers"]["ElvUF_AssistMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,4,603"
	E.db["movers"]["ElvUF_TankMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,4,672"
	E.db["movers"]["ElvUF_TargetCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,1,346"
	E.db["movers"]["BossHeaderMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-283,-260"
	E.db["movers"]["ClassBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,-247,385"
		
	end
	PluginInstallStepComplete.message = ThinkTankUI.Title..L['Unitframes Set']
		PluginInstallStepComplete:Show()
		E:UpdateAll(true)
	
end

local function SetupActionbars(layout)
	-- Actionbars
	E.db["actionbar"]["lockActionBars"] = true

	if layout == 'v1' then
		E.db.actionbars = nil
		
		E.db["actionbar"]["bar1"]["buttonsize"] = 50
		E.db["actionbar"]["bar2"]["buttonsPerRow"] = 6
		E.db["actionbar"]["bar2"]["buttonsize"] = 24
		E.db["actionbar"]["bar2"]["buttonspacing"] = 1
		E.db["actionbar"]["bar2"]["enabled"] = true
		E.db["actionbar"]["bar2"]["inheritGlobalFade"] = true
		E.db["actionbar"]["bar3"]["buttons"] = 12
		E.db["actionbar"]["bar3"]["buttonsize"] = 24
		E.db["actionbar"]["bar3"]["buttonspacing"] = 1
		E.db["actionbar"]["bar3"]["inheritGlobalFade"] = true
		E.db["actionbar"]["bar4"]["alpha"] = 0.75
		E.db["actionbar"]["bar4"]["backdrop"] = false
		E.db["actionbar"]["bar4"]["buttonsize"] = 30
		E.db["actionbar"]["bar4"]["buttonspacing"] = 1
		E.db["actionbar"]["bar4"]["enabled"] = false
		E.db["actionbar"]["bar4"]["inheritGlobalFade"] = true
		E.db["actionbar"]["bar5"]["buttons"] = 12
		E.db["actionbar"]["bar5"]["buttonsPerRow"] = 1
		E.db["actionbar"]["bar5"]["buttonsize"] = 30
		E.db["actionbar"]["bar5"]["buttonspacing"] = 1
		E.db["actionbar"]["bar5"]["enabled"] = false
		E.db["actionbar"]["bar5"]["inheritGlobalFade"] = true
		E.db["actionbar"]["bar6"]["buttons"] = 8
		E.db["actionbar"]["bar6"]["buttonsPerRow"] = 4
		E.db["actionbar"]["bar6"]["buttonsize"] = 24
		E.db["actionbar"]["bar6"]["inheritGlobalFade"] = true
		E.db["actionbar"]["bar6"]["visibility"] = "[vehicleui] hide; [overridebar] hide; [petbattle] hide; show\n\n\n"
		E.db["actionbar"]["barPet"]["backdrop"] = false
		E.db["actionbar"]["barPet"]["buttonsPerRow"] = 10
		E.db["actionbar"]["barPet"]["buttonsize"] = 28
		E.db["actionbar"]["barPet"]["inheritGlobalFade"] = true
		E.db["actionbar"]["font"] = "Expressway"
		E.db["actionbar"]["fontOutline"] = "OUTLINE"
		E.db["actionbar"]["fontSize"] = 12
		E.db["actionbar"]["globalFadeAlpha"] = 0.85
		E.db["actionbar"]["keyDown"] = false
		E.db["actionbar"]["microbar"]["mouseover"] = true
		E.db["actionbar"]["stanceBar"]["buttonsize"] = 25
		E.db["actionbar"]["stanceBar"]["inheritGlobalFade"] = true
		E.db["actionbar"]["stanceBar"]["point"] = "TOPRIGHT"

		-- Movers
		if E.db["movers"] == nil then E.db["movers"] = {} end
		E.db["movers"]["PetAB"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,200"
		E.db["movers"]["ShiftAB"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-419,4"
		E.db["movers"]["ElvAB_6"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-647,4"
		E.db["movers"]["ElvAB_5"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-37,380"
		E.db["movers"]["ElvAB_4"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-448"
		E.db["movers"]["ElvAB_3"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-598,4"
		E.db["movers"]["ElvAB_2"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,598,4"
		E.db["movers"]["ElvAB_1"] = "BOTTOM,ElvUIParent,BOTTOM,0,4"
		
	end
	
	PluginInstallStepComplete.message = ThinkTankUI.Title..L['Actionbars Set']
	PluginInstallStepComplete:Show()
	E:UpdateAll(true)
end

	
local addonNames = {}
local profilesFailed = format('|cff00c0fa%s |r', L["ThinkTankUI: Remastered didn't find any supported addons for profile creation"])
	
local function SetupAddons()
	
	--Details - Settings
	if IsAddOnLoaded("Details") then
		ThinkTankUI:LoadDetailsProfile()
		tinsert(addonNames, 'Details')
	end	
	
	--	Skada - Settings
	if IsAddOnLoaded("Skada") then
		ThinkTankUI:LoadSkadaProfile()
		tinsert(addonNames, 'Skada')
	end
	
	-- Deadly Boss Mods
	if IsAddOnLoaded("DBM-Core") then
		ThinkTankUI:LoadDBMProfile()
		tinsert(addonNames, 'Deadly Boss Mods')
	end
	
	--	AddOnSkins - Settings
	if IsAddOnLoaded("AddOnSkins") then
		ThinkTankUI:LoadAddOnSkinsProfile()
		tinsert(addonNames, 'AddOnSkins')
	end

	--	BigWigs - Settings
	if IsAddOnLoaded("BigWigs") then
		ThinkTankUI:LoadBigWigsProfile()
		tinsert(addonNames, 'BigWigs')
	end
	
	-- MikScrollingBattleText
	if ThinkTankUI:IsAddOnEnabled('MikScrollingBattleText') then
		ThinkTankUI:LoadMSBTProfile()
		tinsert(addonNames, "Mik's Scrolling Battle Text")
	end

	
--	Raven - Settings
	if IsAddOnLoaded("Raven") then
		ThinkTankUI:LoadRavenProfile()
		tinsert(addonNames, 'Raven')
	end

	if checkTable(addonNames) ~= nil then
		local profileString = format('|cfffff400%s |r', L['ThinkTankUI Remastered successfully created and applied profile(s) for:']..'\n')

		tsort(addonNames, function(a, b) return a < b end)
		local names = tconcat(addonNames, ", ")
		profileString = profileString..names

		PluginInstallFrame.Desc4:SetText(profileString..'.')
	else
		PluginInstallFrame.Desc4:SetText(profilesFailed)
	end

	PluginInstallStepComplete.message = ThinkTankUI.Title..L['Addons Set']
	PluginInstallStepComplete:Show()
	twipe(addonNames)
	E:UpdateAll(true)
end

local function InstallComplete()
	E.private.ThinkTankUI.install_complete = ThinkTankUI.Version
		--Set a variable tracking the version of the addon when layout was installed
	E["global"][MyPluginName].profile_name = ElvUI[1].data:GetCurrentProfile()
	E.db[MyPluginName].install_version = ThinkTankUI.Version
	if GetCVarBool("Sound_EnableMusic") then
		StopMusic()
	end

	ReloadUI()

end


ThinkTankUI.ThinkTankUIInstallTable = {
	Name = "|cff9482c9ThinkTankUI Remastered|r",
	Title = L["|cff9482c9ThinkTankUI Remastered|r Installation"],
	tutorialImage = [[Interface\AddOns\ElvUI_ThinkTankUI_RM\media\textures\ThinkTankUI_Remastered]],
	Pages = {
		[1] = function()
			PluginInstallFrame.SubTitle:SetFormattedText(L["Welcome to ThinkTankUI [Remastered] |cff00c0faVersion|r %s, for ElvUI %s."], ThinkTankUI.Version, E.version)
			PluginInstallFrame.Desc1:SetText(L["By pressing the Continue button, ThinkTankUI Remastered will be applied in your current ElvUI installation.\r|cffff8000 TIP: If you apply the changes in a new profile, you can always change back if you don't like the result.|r"])
			PluginInstallFrame.Desc2:SetText(L["Please press the continue button to go onto the next step."])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() InstallComplete() end)
			PluginInstallFrame.Option1:SetText(L["Skip Process"])
		end,
		[2] = function()
			PluginInstallFrame.SubTitle:SetText("Profiles")
			PluginInstallFrame.Desc1:SetText("You can either create a new profile to install ThinkTankUI onto or you can apply ThinkTankUI settings to your current profile")
			PluginInstallFrame.Desc3:SetText("Your currently active ElvUI profile is: |cffc41f3b"..ElvUI[1].data:GetCurrentProfile().."|r")
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() NewProfile(false) end)
			PluginInstallFrame.Option1:SetText("Use Current")
			PluginInstallFrame.Option2:Show()
			PluginInstallFrame.Option2:SetScript("OnClick", function() NewProfile(true, "ThinkTankUI") end)
			PluginInstallFrame.Option2:SetText("Create New")
		
			PluginInstallFrame.SubTitle:SetText("Profiles")
			PluginInstallFrame.Desc1:SetText("Press \"Update Current\" to update your current profile with the new ThinkTankUI changes.")
			PluginInstallFrame.Desc2:SetText("If you'd like to check out what the changes are, without overwriting your current settings, you can press \"Create New\"")
			PluginInstallFrame.Desc3:SetText("Your currently active ElvUI profile is: |cffc41f3b"..ElvUI[1].data:GetCurrentProfile().."|r")
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() NewProfile(false) end)
			PluginInstallFrame.Option1:SetText("Update Current")
			PluginInstallFrame.Option2:Show()
			PluginInstallFrame.Option2:SetScript("OnClick", function() NewProfile(true, "ThinkTankkUI-Update") end)
			PluginInstallFrame.Option2:SetText("Create New")
		end,
		[3] = function()
			PluginInstallFrame.SubTitle:SetText(L["Chat"])
			PluginInstallFrame.Desc1:SetText(L["This is the part where we set up your chat/colors."])
			PluginInstallFrame.Desc2:SetText(L["This button will set up your chat windows."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cffD3CF00Medium|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() SetupChat() end)
			PluginInstallFrame.Option1:SetText(L["Set Chat"])
		end,
		[4] = function()
			PluginInstallFrame.SubTitle:SetText(L["Layout"])
			PluginInstallFrame.Desc1:SetText(L["This is the standard layout for ThinkTankUI Remastered."])
			PluginInstallFrame.Desc2:SetText(L["This will set the Minimap, Databars, and some general settings for ThinkTankUI Remastered "])
			PluginInstallFrame.Desc3:SetFormattedText(L["Importance: |cffFF0000High|r"])

			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript('OnClick', function() SetupLayout(); end) 
			PluginInstallFrame.Option1:SetText("Set Layout")
		end,
		[5] = function()
			PluginInstallFrame.SubTitle:SetText(L["Unitframes"])
			PluginInstallFrame.Desc1:SetText(L["These are the Uniframe Layouts for ThinkTankUI Remastered"])
			PluginInstallFrame.Desc2:SetText(L["This will apply the settings based on the Specialization you choose for |cff9482c9ThinkTankUI Remastered|r. Click the Button to apply these settings. A New Profile should be made for multiple layouts."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cffFF0000High|r"])

			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript('OnClick', function() SetupUnitframes('v1'); end)
			PluginInstallFrame.Option1:SetText("Dps/Tank")
			
			PluginInstallFrame.Option2:Show()
			PluginInstallFrame.Option2:SetScript('OnClick', function() SetupUnitframes('v2'); end)
			PluginInstallFrame.Option2:SetText("Healer")
		end,
		[6] = function()
			PluginInstallFrame.SubTitle:SetText(L["Actionbars"])
			PluginInstallFrame.Desc1:SetText(L["These are the layouts for the 2 types of actionbars for ThinkTankUI Remastered"])
			PluginInstallFrame.Desc2:SetText(L["There are 2 Actionbar Layouts. Make sure to preview them both."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cffFF0000High|r"])

			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript('OnClick', function() SetupActionbars('v1'); end) 
			PluginInstallFrame.Option1:SetText("Set Actionbars")
		end,
		[7] = function()
			PluginInstallFrame.SubTitle:SetText(L["Addon Profiles"])
			PluginInstallFrame.Desc1:SetText(L["Creates Addon Profiles for ThinkTankUI Remastered."])
			PluginInstallFrame.Desc2:SetText()
			PluginInstallFrame.Desc3:SetText(L["Importance: |cffD3CF00High|r"])

			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript('OnClick', function() SetupAddons() end)
			PluginInstallFrame.Option1:SetText("Set Addon Profiles")
		end,
		[8] = function()
			PluginInstallFrame.SubTitle:SetText(L["Installation Complete"])
			PluginInstallFrame.Desc1:SetText(L["You are now finished with the installation process. If you are in need of technical support please visit us at http://www.tukui.org."])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below so you can setup variables and ReloadUI."])

			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", InstallComplete)
			PluginInstallFrame.Option1:SetText(L["Installed"])
		end,
	},
	StepTitles = {
		 [1] = START,
		 [2] = L["Profile Creation"],
		 [3] = L["Chat Setup"],
		 [4] = L["General Layout"],
		 [5] = L["Unitframes"],
		 [6] = L["Actionbars"],
		 [7] = L["Addon Profiles"],
		 [8] = L["Installation Complete"],
	},
	StepTitlesColor = {1, 1, 1},
	StepTitlesColorSelected = {0, 179/255, 1},
	StepTitleWidth = 200,
	StepTitleButtonWidth = 180,
	StepTitleTextJustification = "RIGHT",

}

